@@ -9,11 +9,11 @@ Pg::Explain::FromText - Parser for text based explains
 
 =head1 VERSION
 
-Version 0.60
+Version 0.61
 
 =cut
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 =head1 SYNOPSIS
 
@@ -55,6 +55,10 @@ sub parse_source {
 
     LINE:
     for my $line ( @lines ) {
+
+        # There could be stray " at the end. No idea why, but some people paste such explains on explain.depesz.com
+        $line =~ s/"\z//;
+
         if (
             my @catch =
             $line =~ m{
